@@ -1,10 +1,9 @@
 import os
 import configparser
-import sys
 
 
 class Setup:
-    def start_config(self, config):
+    def start_sconfig(self, config):
         default = 'default'
         config.add_section('default')
 
@@ -33,9 +32,6 @@ class Setup:
                 print("No changes done")
                 return False
             else:
-                self.start_config(config)
+                return self.start_sconfig(config)
         else:
-            self.start_config(config)
-        print("Setup DONE")
-        print("Exiting from program, need restart after setup")
-        sys.exit()
+            return self.start_sconfig(config)
